==> core_models-0.2.2.gem: app/controllers/core_models/i18n/dialects_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class I18n::DialectsController < CoreModelsController
    # GET /i18n/dialects
    # GET /i18n/dialects.json
    def index
      @i18n_dialects = I18n::Dialect.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @i18n_dialects }
      end
    end

    # GET /i18n/dialects/1
    # GET /i18n/dialects/1.json
    def show
      @i18n_dialect = I18n::Dialect.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @i18n_dialect }
      end
    end

    # GET /i18n/dialects/new
    # GET /i18n/dialects/new.json
    def new
      @i18n_dialect = I18n::Dialect.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @i18n_dialect }
      end
    end

    # GET /i18n/dialects/1/edit
    def edit
      @i18n_dialect = I18n::Dialect.find(params[:id])
    end

    # POST /i18n/dialects
    # POST /i18n/dialects.json
    def create
      @i18n_dialect = I18n::Dialect.new(params[:i18n_dialect])

      respond_to do |format|
        if @i18n_dialect.save
          format.html { redirect_to @i18n_dialect, :notice => 'Dialect was successfully created.' }
          format.json { render :json => @i18n_dialect, :status => :created, :location => @i18n_dialect }
        else
          format.html { render :action => "new" }
          format.json { render :json => @i18n_dialect.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /i18n/dialects/1
    # PUT /i18n/dialects/1.json
    def update
      @i18n_dialect = I18n::Dialect.find(params[:id])

      respond_to do |format|
        if @i18n_dialect.update_attributes(params[:i18n_dialect])
          format.html { redirect_to @i18n_dialect, :notice => 'Dialect was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @i18n_dialect.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /i18n/dialects/1
    # DELETE /i18n/dialects/1.json
    def destroy
      @i18n_dialect = I18n::Dialect.find(params[:id])
      @i18n_dialect.destroy

      respond_to do |format|
        format.html { redirect_to i18n_dialects_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/i18n/dialects_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class I18n::DialectsController < CoreModelsController
    # GET /i18n/dialects
    # GET /i18n/dialects.json
    def index
      @i18n_dialects = I18n::Dialect.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @i18n_dialects }
      end
    end

    # GET /i18n/dialects/1
    # GET /i18n/dialects/1.json
    def show
      @i18n_dialect = I18n::Dialect.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @i18n_dialect }
      end
    end

    # GET /i18n/dialects/new
    # GET /i18n/dialects/new.json
    def new
      @i18n_dialect = I18n::Dialect.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @i18n_dialect }
      end
    end

    # GET /i18n/dialects/1/edit
    def edit
      @i18n_dialect = I18n::Dialect.find(params[:id])
    end

    # POST /i18n/dialects
    # POST /i18n/dialects.json
    def create
      @i18n_dialect = I18n::Dialect.new(params[:i18n_dialect])

      respond_to do |format|
        if @i18n_dialect.save
          format.html { redirect_to @i18n_dialect, :notice => 'Dialect was successfully created.' }
          format.json { render :json => @i18n_dialect, :status => :created, :location => @i18n_dialect }
        else
          format.html { render :action => "new" }
          format.json { render :json => @i18n_dialect.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /i18n/dialects/1
    # PUT /i18n/dialects/1.json
    def update
      @i18n_dialect = I18n::Dialect.find(params[:id])

      respond_to do |format|
        if @i18n_dialect.update(params[:i18n_dialect])
          format.html { redirect_to @i18n_dialect, :notice => 'Dialect was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @i18n_dialect.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /i18n/dialects/1
    # DELETE /i18n/dialects/1.json
    def destroy
      @i18n_dialect = I18n::Dialect.find(params[:id])
      @i18n_dialect.destroy

      respond_to do |format|
        format.html { redirect_to i18n_dialects_url }
        format.json { head :no_content }
      end
    end
  end
end
